@@ -201,6 +201,7 @@ window.WAPI._serializeChatObj = (obj) => {
     return null;
   }
   return Object.assign(window.WAPI._serializeRawObj(obj), {
+    id: obj.id._serialized,
     kind: obj.kind,
     isGroup: obj.isGroup,
     formattedTitle: obj.formattedTitle,
@@ -216,6 +217,7 @@ window.WAPI._serializeContactObj = (obj) => {
     return null;
   }
   return Object.assign(window.WAPI._serializeRawObj(obj), {
+    id: obj.id._serialized,
     formattedName: obj.formattedName,
     isHighLevelVerified: obj.isHighLevelVerified,
     isMe: obj.isMe,
@@ -709,13 +711,13 @@ window.WAPI._getGroupParticipants = async function (id) {
  */
 window.WAPI.getGroupParticipantIDs = async function (id) {
   return (await WAPI._getGroupParticipants(id))
-    .map((participant) => participant.id);
+    .map((participant) => participant.id._serialized);
 };
 
 window.WAPI.getGroupAdmins = async function (id) {
   return (await WAPI._getGroupParticipants(id))
     .filter((participant) => participant.isAdmin)
-    .map((admin) => admin.id);
+    .map((admin) => admin.id._serialized);
 };
 
 /**
